@@ -6,6 +6,9 @@ import json
 import uuid
 from function_scheduling_distributed_framework.utils import RedisMixin, decorators
 
+"""
+此模块是依赖redis的确认消费，所以比较复杂。
+"""
 
 # noinspection PyUnresolvedReferences
 class ConsumerConfirmMixinWithTheHelpOfRedis(RedisMixin):
@@ -23,8 +26,9 @@ class ConsumerConfirmMixinWithTheHelpOfRedis(RedisMixin):
 
     def start_consuming_message(self):
         self.logger.warning('启动了任务redis确认消费助手')
-        self.keep_circulating(60, block=False)(self._requeue_tasks_which_unconfirmed)()
         super().start_consuming_message()
+        self.keep_circulating(60, block=False)(self._requeue_tasks_which_unconfirmed)()
+
 
     def _add_task_str_to_unack_zset(self, task_str, ):
         self.redis_db_frame.zadd(self._unack_zset_name, task_str, time.time())
